<?php declare(strict_types=1);

namespace App\Controller;

use App\Form\UserNameFormType;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Cookie;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;

final class HomeController extends AbstractController
{
    public const string DEFAULT_USERNAME = 'nobody';

    #[Route('/', name: 'home')]
    public function home(UrlGeneratorInterface $router): Response
    {
        return new RedirectResponse($router->generate('app_food_order_index'));
    }

    #[Route('/username', name: 'username')]
    public function usernameForm(Request $request, UrlGeneratorInterface $router): Response
    {
        $form = $this->createForm(UsernameFormType::class);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $username = $form->getData()['username'] ?? self::DEFAULT_USERNAME;
            $response = new RedirectResponse($router->generate('app_food_order_index'));
            if ($username === self::DEFAULT_USERNAME || $username === '') {
                $response->headers->clearCookie('username');
                return $response;
            }
            $response->headers->setCookie(new Cookie('username', $username));
            return $response;
        }
        $username = $request->cookies->get('username', self::DEFAULT_USERNAME);
        $form->setData([
            'username' => $username,
        ]);
        return $this->render('username.html.twig', [
            'form' => $form,
        ]);
    }
}
